from setuptools import setup

setup(
    name='PyMesaHandler',
    version='0.2.0',
    packages=['MesaHandler'],
    url='https://github.com/muma7490/PyMesaHandler',
    license='MIT',
    author='Marco Müllner',
    author_email='muellnermarco@gmail.com',
    description='An easy way to handle Mesa using Python',
    long_description=open('README.md').read(),
    install_requires=[
        'numpy',
    ]
)
